Package: JohnsonKinaseData
Title: Kinase PWMs based on data published by Johnson et al. 2023 and
        Yaron-Barir et al. 2024
Version: 1.8.0
Date: 2023-09-24
Authors@R: 
    person("Florian", "Geier", , "florian.geier@unibas.ch", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-9076-9264"))
Description: The packages provides position specific weight matrices (PWMs) for 303 human serine/threonine and 93 tyrosine kinases originally published in Johnson et al. 2023 (doi:10.1038/s41586-022-05575-3) and Yaron-Barir et al. 2024 (doi:10.1038/s41586-024-07407-y). The package includes basic functionality to score user provided phosphosites. It also includes pre-computed PWM scores ("background scores") for a large collection of curated human phosphosites which can be used to rank PWM scores relative to the background scores ("percentile rank").
License: MIT + file LICENSE
URL: https://github.com/fgeier/JohnsonKinaseData/
BugReports: https://support.bioconductor.org/t/JohnsonKinaseData
Imports: ExperimentHub, BiocParallel, checkmate, dplyr, stats, stringr,
        tidyr, purrr, utils
Suggests: knitr, BiocStyle, ExperimentHubData, testthat (>= 3.0.0),
        rmarkdown
biocViews: ExperimentHub, Homo_sapiens_Data, Proteome
VignetteBuilder: knitr
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/JohnsonKinaseData
git_branch: RELEASE_3_23
git_last_commit: 087607c
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-05-05
NeedsCompilation: no
Packaged: 2026-05-05 15:30:06 UTC; biocbuild
Author: Florian Geier [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9076-9264>)
Maintainer: Florian Geier <florian.geier@unibas.ch>
Depends: R (>= 4.1.0)
